@@ -1,11 +1,12 @@
 package Pithub;
 BEGIN {
-  $Pithub::VERSION = '0.01009';
+  $Pithub::VERSION = '0.01010';
 }
 
 # ABSTRACT: Github v3 API
 
 use Moo;
+use Pithub::Events;
 use Pithub::Gists;
 use Pithub::GitData;
 use Pithub::Issues;
@@ -17,6 +18,11 @@ extends 'Pithub::Base';
 
 
 
+sub events {
+    return shift->_create_instance('Pithub::Events');
+}
+
+
 sub gists {
     return shift->_create_instance('Pithub::Gists');
 }
@@ -63,7 +69,7 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01009
+version 0.01010
 
 =head1 SYNOPSIS
 
@@ -94,6 +100,10 @@ L<Pithub> supports all API calls so far, but only for v3.
 
 =head1 METHODS
 
+=head2 events
+
+Provides access to L<Pithub::Events>.
+
 =head2 gists
 
 Provides access to L<Pithub::Gists>.
@@ -185,6 +195,15 @@ use it.
 
 =item *
 
+L<Pithub::Events>
+
+See also: L<http://developer.github.com/v3/events/>
+
+    my $gists = Pithub->new->events;
+    my $gists = Pithub::Events->new;
+
+=item *
+
 L<Pithub::Gists>
 
 See also: L<http://developer.github.com/v3/gists/>
